import { ApiProperty } from "@nestjs/swagger";
import {
  IsEmail,
  IsNotEmpty,
  IsOptional,
  IsPhoneNumber,
  IsString,
} from "class-validator";
import { UserRoles } from "../enums/user.roles";

export class CreateUserDTO {
  @ApiProperty({
    description: "First name of the user",
    type: String,
    required: true,
    example: "John",
  })
  @IsString()
  @IsNotEmpty()
  firstName: string;

  @ApiProperty({
    description: "Last name of the user",
    type: String,
    required: true,
    example: "Doe",
  })
  @IsString()
  @IsNotEmpty()
  lastName: string;

  @ApiProperty({
    description: "Username",
    type: String,
    required: true,
    example: "john.doe",
  })
  @IsString()
  @IsNotEmpty()
  username: string;

  @ApiProperty({
    description: "password",
    type: String,
    required: true,
    example: "123",
  })
  @IsString()
  @IsNotEmpty()
  password: string;

  @ApiProperty({
    description: "Email address",
    type: String,
    required: true,
    example: "john.doe@gmail.com",
  })
  @IsString()
  @IsNotEmpty()
  @IsEmail()
  email: string;

  @ApiProperty({
    description: "Phone number",
    type: String,
    required: false,
    example: "+3305 2312 5403",
    nullable: true,
  })
  @IsString()
  @IsOptional()
  @IsPhoneNumber()
  phoneNumber?: string;

  @ApiProperty({
    description: "User role",
    required: false,
    type: String,
    enum: UserRoles,
    default: UserRoles.CUSTOMER,
    example: UserRoles.CUSTOMER,
  })
  @IsString()
  @IsOptional()
  role?: string;
}
