import { Injectable, UnauthorizedException } from "@nestjs/common";
import { ConfigService } from "@nestjs/config";
import { PassportStrategy } from "@nestjs/passport";
import { Request } from "express";
import { Strategy } from "passport-jwt";
import { Payload } from "../types/jwt-payload.interface";
import { UserReq } from "../types/user-req.interface";

@Injectable()
export class JwtStrategy extends PassportStrategy(Strategy) {
  constructor(private readonly configService: ConfigService) {
    super({
      jwtFromRequest: (req: Request) => {
        if (!req?.cookies?.access_token) {
          throw new UnauthorizedException("No token found in cookies");
        }

        return req.cookies.access_token;
      },
      ignoreExpiration: false,
      secretOrKey: configService.get<string>("SECRET"),
    });
  }

  async validate(payload: Payload): Promise<UserReq> {
    return { id: payload.sub, username: payload.username, role: payload.role };
  }
}
